0.9.0 (26-06-2019)
==================
- Libs updaten - security alert (#140)
- Mobiele layout verbeteren (#139)

0.8.0 (22-02-2019)
==================
- Header - contact & over ons links (#135)

0.7.0 (18-07-2018)
==================
- Updaten van GA macro (#125)
- Aanpassen kleur active in menubar (#124)

0.6.0 (04-07-2018)
==================

- Fix jquery versie in public scaffold bower.json (#97)
- admin bower.json template updaten (#98)
- Display aangemelde gebruiker in geval gebruiker geen Actor object heeft (#104)
- Aanpassen link color (#110)
- Privacybeleid link in footer (#116)

0.5.0 (27-0-2018)
==================

* Added new jinja2 filter specific for formatting fuzzy_dates (also for dates before 1900)

0.4.8 (22-03-2018)
==================

* Updates/aanpassingen voor oa Inventaris (#109)

0.4.7 (02-02-2017)
==================

* bugfix datum
* favicon
* IE compatibility
* link ict mailbox

0.4.6 (30-06-2016)
==================

* bugfix in code voor dropdowns

0.4.5 (29-06-2016
=================

* mogelijkheid toegevoegd om dropdown in het menu te tonen
* enkele verbeteringen in de error pagina's
* uitlijning van de Vlaanderen banners
* verschillende verbeteringen voor de admin stijl

0.4.4 (03-02-2016)
==================

* Proces scaffold toegevoegd
* verbeterde error page templates
* nieuw Home icon
* verbeterde footer links
* social media links toegevoegd
* verschillende stijl verbeteringen
* update naar jinja2 2.8

0.4.3 (02-07-2015)
==================

* Bugfix error pages
* Lijstweergave zoekresultaten aangepast
* Detailpagina besluitentype geupdate
* zoekwidget toegevoegd

0.4.2 (09-06-2015)
==================

* Kleine layout fixes
* Admin interface update

0.4.1 (29-05-2015)
==================
* Toevoegen van een textarea element met een inline label 
* Toevoegen van een checkbox met een placeholder
* Toevoegen van een generieke profile template
* Toevoegen van een macro om een URI voor een resource te genereren
* Toevoegen van een generiek datetime format filter
* Opkuisen van het project
* Schrijven van nieuwe tests om coverage te vergroten

0.4.0 (24-04-2015)
==================

* fix voor favicon
* Speciale input velden toegevoegd
* Voorbeeldtemplates verder uitgewerkt
* Generieke 404/500 templates toegevoegd
* Alertblock toegevoegd
* Mediaqueries toegevoegd die problemen met header op mobile devices oplost
* Problemen met footer verholpen

0.3.3 (04-03-2015)
==================
* Fix voor gebruikersnamen
* Documentatie geupdate ivm admin scaffold

0.3.2 (26-02-2015)
==================
* Aanpassingen vooral aan admin scaffold


0.3.1 (23-02-2015)
==================

* Admin scaffold toegevoegd
* Aanmelden/Afmelden knop toegevoegd
* Google analytics geupdate naar Universal analytics
* Font-awesome toegevoegd als bower dependency

0.3.0 (12-02-2015)
==================

* Erfgoedstijl aangepast aan vereisten van de nieuwe Vlaamse Huisstijl


0.2.1 (25-11-2014)
==================

* Released as open source on PyPI.
* Copyright date can be changed again. Now works with a variable instead of 
  a block.

0.2.0 (14-08-2014)
==================

* Andere manier van omgaan met Foundation dependency. Gaat nu via bower.
* Upgraden naar Foundation 5.3.x. Bower zal steeds de laatste versie in de 5.3
  reeks proberen aan te houden.
* Toevoegen van Foundation Icon Fonts 3
* Unit tests naar py.test ipv nose.
* Basistemplate is nu meer responsive dan vroeger.
* Standaard breedte van de css grid werd nu gelijk geschakeld met die van de
  corporate site.
* Footer werd gewijzigd zodat er blauw over de ganse breedte is.

0.1.1 (06-08-2014)
==================

* Toevoegen van een mogelijkheid om css_files in de html header te injecteren. (#7) [JonathanGeosolutions]
* Toevoegen van een mogelijkheid om de HTML header te overriden in een template.
* Testen ook laten uitvoeren op py33 en py34.

0.1.0
=====

* Eerste stabiele release.
* Maakt nu gebruik van onze eigen typekit code.

0.1.0b2
=======

* Terug naar TypeKit. Voorlopig gebruiken we de account van Glue. Op een bepaald
  moment zal iemand wel eens voor onze eigen accout moeten betalen.

0.1.0b1
=======

* Extra documentatie met sphinx. (#5)
* Static files zoals favicon en robots.txt kunnen geleverd worden door pyoes. (#6)
* Niet meer nodig om pyoes:static view te includen. Vanaf nu moet pyoes zelf 
  wel geinclude worden, deze handelt dan de rest af.
* De scaffold zal meteen een sass bestand voor de applicatie specifieke css
  aanmaken.

0.1.0a3
=======

* Overschakelen op open fonts. (#4)
* Js files kunnen doorgegeven worden door extended templates. (#3)
* Verwijderen van een onbestaande dit in het install_compass_extensions script werkt. (#1)
* Docs wat uitgebreid. (#2)
* Layout van de breadcrumbs wat compacter gemaakt.

0.1.0a2
=======

* Zorgend dat jquery protocol onafhankelijk kan geladen worden. Gaf problemen 
  op https sites.

0.1.0a1
=======

* eerste versie die getagged wordt
* aantal jinja2 templates
* sass files
* nog zeer onvolledig en met gebrekkige documentatie
